summaryrefslogtreecommitdiffstats
path: root/filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h')
-rw-r--r--filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h b/filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h
index 3ad39ea6..60652330 100644
--- a/filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h
+++ b/filesharing/advanced/kcm_sambaconf/filemodedlgimpl.h
@@ -39,8 +39,8 @@ class QLineEdit;
/**
* Small dialog to change the UNIX access rights
* It is called with a QLineEdit as parameter.
* The class then takes the text from the QLineEdit and
* interprets it as an oktal UNIX access right string
* e.g. 0744
* After the user has changed the access rights with the dialog
@@ -52,10 +52,10 @@ class FileModeDlgImpl : public FileModeDlg
{
Q_OBJECT
public:
- FileModeDlgImpl(QWidget* parent, QLineEdit* edit);
+ FileModeDlgImpl(TQWidget* parent, TQLineEdit* edit);
~FileModeDlgImpl();
protected:
- QLineEdit* _edit;
+ TQLineEdit* _edit;
void init();
protected slots:
virtual void accept();
@@ -39,8 +39,8 @@ class QLineEdit;
/**
* Small dialog to change the UNIX access rights
- * It is called with a QLineEdit as parameter.
- * The class then takes the text from the QLineEdit and
+ * It is called with a TQLineEdit as parameter.
+ * The class then takes the text from the TQLineEdit and
* interprets it as an oktal UNIX access right string
* e.g. 0744